# SPDX-FileCopyrightText: 2020 Dan Halbert, written for Adafruit Industries
#
# SPDX-License-Identifier: Unlicense

# Test works for boards with onboard adapters.

import _bleio

from adafruit_airlift.esp32 import ESP32

esp32 = ESP32()
adapter = esp32.start_bluetooth()
_bleio.set_adapter(adapter)

print(_bleio.adapter.address)



# SPDX-FileCopyrightText: Copyright (c) 2020 Dan Halbert for Adafruit Industries
#
# SPDX-License-Identifier: MIT
"""
`adafruit_airlift`
================================================================================

Manage AirLift coprocessors for use with Wifi and Bluetooth


* Author(s): Dan Halbert

Implementation Notes
--------------------

**Software and Dependencies:**

* Adafruit CircuitPython firmware for the supported boards:
  https://github.com/adafruit/circuitpython/releases
"""

# imports

__version__ = "1.0.18"
__repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_AirLift.git"
